@@ -23,7 +23,7 @@ use XML::Smart::Tie ;
 use XML::Smart::Tree ;
 
 our ($VERSION) ;
-$VERSION = '1.5.9' ;
+$VERSION = '1.6.1' ;
 
 ###############
 # AUTOLOADERS #
@@ -35,6 +35,12 @@ sub data {
   &XML::Smart::Data::data(@_) ;
 }
 
+sub apply_dtd {
+  require XML::Smart::DTD ;
+  *apply_dtd = \&XML::Smart::DTD::apply_dtd ;
+  &XML::Smart::DTD::apply_dtd(@_) ;
+}
+
 sub xpath { _load_xpath() ; &XML::Smart::XPath::xpath(@_) ;}
 sub XPath { _load_xpath() ; &XML::Smart::XPath::XPath(@_) ;}
 sub xpath_pointer { _load_xpath() ; &XML::Smart::XPath::xpath_pointer(@_) ;}
@@ -64,7 +70,7 @@ sub NO_XML_PARSER {
 sub new {
   my $class = shift ;
   my $file = shift ;
-  my $parser = shift ;
+  my $parser = ($_[0] !~ /^(?:uper|low|arg|on|no|use)\w+$/i) ? shift(@_) : '' ;
   
   my $this = Object::MultiType->new(
   boolsub   => \&boolean ,
@@ -644,7 +650,7 @@ sub set_node {
     delete $$nodes{$key} ;
     my @keys = keys %$this ;
     if ( $#keys == 0 && @keys[0] eq 'CONTENT') {
-      my $content = $this->{CONTENT}('.') ;
+      my $content = !$this->{CONTENT}->null ? $this->{CONTENT}('.') : $this->content ;
       $this->back->pointer->{$key} = $content ;
     }
   }
@@ -925,6 +931,7 @@ sub find_arg {
       my $data ;
       if ($name =~ /^content$/i) { $name = 'CONTENT' ;}
       $data = ref($hash) eq 'HASH' ? $$hash{$name} : $hash ;
+      $data = $$data{CONTENT} if ref($data) eq 'HASH' ;
       
       if    ($type eq 'eq'  && $data eq $value)     { push(@hash,$hash_i) ; push(@i,$i) ; last ;}
       elsif ($type eq 'ne'  && $data ne $value)     { push(@hash,$hash_i) ; push(@i,$i) ; last ;}
@@ -987,6 +994,10 @@ sub content {
   my $key = 'CONTENT' ;
   my $i = $$this->{i} ;
   
+  if (ref($$this->{point}) eq 'ARRAY') {
+    return $this->[0]->content ;
+  }
+  
   if ( ref($$this->{point}) ne 'HASH' ) { return '' ;}
   
   if (ref($$this->{point}{$key}) eq 'ARRAY') {
@@ -1100,6 +1111,20 @@ XML::Smart:
 
 I<XML::Smart::HTMLParser> can be used to load/parse wild/bad XML data, or HTML tags.
 
+=head1 Tutorial and F.A.Q.
+
+You can find some extra documents about I<XML::Smart> at:
+
+=over 4
+
+=item L<XML::Smart::Tutorial> - Tutorial and examples for XML::Smart.
+
+=item L<XML::Smart::FAQ> - Frequently Asked Questions about XML::Smart.
+
+=back
+
+=cut
+
 =head1 USAGE
 
   ## Create the object and load the file:
@@ -1264,6 +1289,10 @@ Here's the tree of the example above:
                        },
             },
 
+=item use_spaces
+
+Accept contents that have only spaces.
+
 =item on_start (CODE) I<*optional>
 
 Code/sub to call on start a tag.
@@ -1317,6 +1346,17 @@ B<Examples of use:>
              }
   ) ;
 
+=head2  apply_dtd (DTD)
+
+Apply the I<DTD> to the XML tree.
+
+I<DTD> can be a source, file, GLOB or URL.
+
+This method is usefull if you need to have the XML generated by I<data()>
+formated in a specific DTD, so, elements will be nodes automatically,
+attributes will be checked, required elements and attributes will be created,
+the element order will be set, etc...
+
 =head2  args()
 
 Return the arguments names (not nodes).
@@ -1440,6 +1480,10 @@ B<Options:>
 
 =over 10
 
+=item nodtd
+
+Do not add in the XML content the DTD applied by the method I<apply_dtd()>.
+
 =item noident
 
 If set to true the data isn't idented.
